@@ -10,7 +10,6 @@ import sys
 import traceback
 
 import cherrypy
-import dispatch
 try:
 #    # python 2.5 ?
     from xml.etree import cElementTree as et
@@ -67,9 +66,13 @@ def wsexpose(return_type=basestring):
                           allow_json=True)(dict_wrapped_result(func))
         
         def newfunc(self, **kw):
+            jsonp = None
             if "tg_format" in kw:
                 if kw["tg_format"] == "json":
                     cherrypy.request.headers["Accept"] = "text/javascript"
+                    # Intercept jsonp parameter if passed along.
+                    if kw.has_key("jsonp"):
+                        jsonp = kw.pop("jsonp")
                 else:
                     cherrypy.request.headers["Accept"] = "text/xml"
                 del kw["tg_format"]
@@ -93,6 +96,16 @@ def wsexpose(return_type=basestring):
             
             if "xml_body" in kw:
                 kw = iconv.handle_xml_params(kw["xml_body"], input_types)
+            elif "_xml_request" in kw:
+                try:
+                    data = kw["_xml_request"]
+                    body = et.fromstring(data)
+                except SyntaxError:
+                    raise validators.Invalid("Request XML is invalid", "",
+                                             None)
+                kw = iconv.handle_xml_params(body, input_types)
+            elif "_json_request" in kw:
+                kw = iconv.handle_json_params(kw["_json_request"], input_types)
             elif request.headers.get("Content-Type", "") \
                  .startswith("text/xml"):
                 try:
@@ -117,7 +130,10 @@ def wsexpose(return_type=basestring):
                 else:
                     # when direct traversal is used, call the standard
                     # TurboGears expose mechanism.
-                    return tgfunc(self, **kw)
+                    outp = tgfunc(self, **kw)
+                    if jsonp:
+                        outp = jsonp + "(" + outp + ");"
+                    return outp
             except TypeError:
                 # handle the case where a bogus parameter was sent in to the
                 # function
@@ -167,6 +183,19 @@ def wsvalidate(*args, **kw):
             input_types[fi.params[i]] = argtype
         
         input_types.update(kw)
+
+        # Make sure all of the input types are registered
+        # so they show up in the WSDL.
+        for argname, argtype in input_types.items():
+            if isinstance(argtype, list):
+                typetoreg = argtype[0]
+            else:
+                typetoreg = argtype
+            if typetoreg not in primitives:
+                log.info('registering complex type %s for %s',
+                         typetoreg, argname)
+                register_complex_type(fi, typetoreg)
+
         fi.input_types = input_types
         return func
     return entangle
