@@ -81,13 +81,14 @@ def ctvalues(cls):
     """Inspects a class for the defined default values. This is used to
     figure out the types of attributes that instances of the class will
     be expected to have (to provide useful information for statically
-    typed languages). It will strip out any attributes that start with _
-    and any methods.
+    typed languages). It will strip out any attribute that starts with _,
+    any method, and any property that is not a typedproperty.
     
     @param cls class to inspect
     @return list of keys that are likely holders of useful data"""
     return [key for key in dir(cls) if not key.startswith("_") and not 
-            isinstance(getattr(cls, key), types.MethodType)]
+            isinstance(getattr(cls, key), types.MethodType) and not
+            type(getattr(cls, key)) == property]
 
 def _setup_new_type(cls):
     cls._type_dependents = 0
@@ -132,4 +133,4 @@ def register_complex_type(fi, cls):
                 _setup_new_type(checkitem)
             checkitem._type_dependents += 1
             register_complex_type(fi, checkitem)
-        
\ No newline at end of file
+        
