@@ -15,6 +15,12 @@ class MyService(WebServicesRoot):
     def twentyover(self, value):
         "Divides 20 by value"
         return 20 / value
+
+    @wsexpose(int)
+    @wsvalidate([int])
+    def sum(self, values):
+        "Sum all the values"
+        return sum(values)
     
 class FancyValue(object):
     name = ""
