@@ -13,6 +13,20 @@ def test_simple():
     print output
     assert output == """{"result": 10}"""
 
+def test_jsonp():
+    cherrypy.root = MyService("http://foo.bar.baz")
+    testutil.create_request("/times2?value=5&tg_format=json&jsonp=myFunc")
+    output = cherrypy.response.body[0]
+    print output
+    assert output == """myFunc({"result": 10});"""
+
+def test_simple_array():
+    cherrypy.root = MyService("http://foo.bar.baz")
+    testutil.create_request("/sum?values=5&values=10&tg_format=json")
+    output = cherrypy.response.body[0]
+    print output
+    assert output == """{"result": 15}"""
+
 def test_nested_top():
     cherrypy.root = OuterService("http://foo.bar.baz")
     testutil.create_request("/ultimatequestion", 
@@ -88,6 +102,28 @@ def test_complex_input():
     print cherrypy.root.last_person.age
     assert cherrypy.root.last_person.age == 32
 
+def test_complex_input_on_get():
+    cherrypy.root = ComplexService("http://foo.bar.baz/")
+    
+    request = """{"person":{"name":"Fred","age":22}}"""
+    testutil.create_request(
+        "/tenyearsolder?tg_format=json&_json_request=%s" % request)
+    output = cherrypy.response.body[0]
+    print output
+    print cherrypy.root.last_person.age
+    assert cherrypy.root.last_person.age == 32
+
+def test_complex_params_on_get():
+    cherrypy.root = ComplexService("http://foo.bar.baz/")
+    
+    person = """{"name":"Fred","age":22}"""
+    testutil.create_request(
+        "/tenyearsolder?tg_format=json&person=%s" % person)
+    output = cherrypy.response.body[0]
+    print output
+    print cherrypy.root.last_person.age
+    assert cherrypy.root.last_person.age == 32
+
 def test_rwprop():
     cherrypy.root = ComplexService("http://foo.bar.baz/")
     
