@@ -283,11 +283,11 @@ def test_documentation_strings():
     root = et.fromstring(output)
     porttype = root.findall(".//{http://schemas.xmlsoap.org/wsdl/}portType")[0]
     operation = porttype.getchildren()[0]
-    assert operation.attrib["name"] == "times2"
+    assert operation.attrib["name"] == "sum"
     docelems = operation.findall(
                 ".//{http://schemas.xmlsoap.org/wsdl/}documentation")
     assert len(docelems) == 1
-    assert docelems[0].text == "Multiplies value by two."
+    assert docelems[0].text == "Sum all the values"
 
 def test_fault_for_invalid_input():
     cherrypy.root = MyService("http://foo.bar.baz")
