@@ -39,6 +39,31 @@ def test_complex_input():
     assert output == """<result><age>32</age><computed>Hello!</computed>""" \
                      """<name>Fred</name></result>"""
 
+def test_complex_input_on_get():
+    cherrypy.root = ComplexService("http://foo.bar.baz/")
+    request = """<request><person><name>Fred</name><age>22</age></person></request>"""
+    testutil.create_request("/tenyearsolder?tg_format=xml&_xml_request=%s" % request)
+    print cherrypy.response.headers["Content-Type"]
+    assert cherrypy.response.headers["Content-Type"] == "text/xml; charset=utf-8"
+    output = cherrypy.response.body[0]
+    print output
+    assert output == """<result><age>32</age><computed>Hello!</computed>""" \
+                     """<name>Fred</name></result>"""
+
+
+def test_complex_params():
+    cherrypy.root = ComplexService("http://foo.bar.baz/")
+    person = """<person><name>Fred</name><age>22</age></person>
+"""
+    testutil.create_request("/tenyearsolder?tg_format=xml&person=%s" % person)
+    print cherrypy.response.headers["Content-Type"]
+    assert cherrypy.response.headers["Content-Type"] == "text/xml; charset=utf-8"
+    output = cherrypy.response.body[0]
+    print output
+    assert output == """<result><age>32</age><computed>Hello!</computed>""" \
+                     """<name>Fred</name></result>"""
+
+
 def test_rwproperty():
     cherrypy.root = ComplexService("http://foo.bar.baz/")
     request = """<request>
