@@ -1,31 +1,31 @@
 """A template plugin that generates simple XML"""
 from genshi.builder import Element
 
-import dispatch
+from peak.rules import abstract, when
 
 from tgwebservices.runtime import primitives, ctvalues, typedproperty
 
 _simplevalues = set([int, long, float, bool])
 _strvalues = set([basestring, str, unicode])
 
-@dispatch.generic()
+@abstract()
 def xml_value(name, value):
     """Converts a value into XML Element objects."""
     pass
 
-@xml_value.when("type(value) in _strvalues")
+@when(xml_value, "type(value) in _strvalues")
 def xml_string(name, value):
     elem = Element(name)
     elem(value)
     return elem
  
-@xml_value.when("type(value) in _simplevalues")
+@when(xml_value, "type(value) in _simplevalues")
 def xml_simple(name, value):
     elem = Element(name)
     elem(str(value))
     return elem
 
-@xml_value.when("type(value) not in primitives")
+@when(xml_value, "type(value) not in primitives")
 def xml_instance(name, value):
     """Handles an instance of a complex type."""
     elem = Element(name)
@@ -34,14 +34,14 @@ def xml_instance(name, value):
         elem.append(xml_value(key, getattr(value, key)))
     return elem
 
-@xml_value.when("isinstance(value, list)")
+@when(xml_value, "isinstance(value, list)")
 def xml_list(name, value):
     elem = Element(name)
     for item in value:
         elem.append(xml_value("item", item))
     return elem
 
-@xml_value.when("isinstance(value, dict)")
+@when(xml_value, "isinstance(value, dict)")
 def xml_dict(name, value):
     elem = Element(name)
     for key in value.keys():
